% create the STERN STUDY
eeglab
basedir = pwd;
subjs = {'S01' 'S02' 'S03' 'S04' 'S05' 'S06' 'S07' ...
         'S08' 'S09' 'S10' 'S11' 'S12' 'S13'};
commands = {}; % initialize STUDY dataset list

% Now loop through subjects and add to the STUDY
for subj = 1:length(subjs) % for each subject
    fileIgnore   = fullfile(basedir, subjs{subj}, 'Ignore.set');
    fileMemorize = fullfile(basedir, subjs{subj}, 'Memorize.set');
    fileProbe    = fullfile(basedir, subjs{subj}, 'Probe.set');
    commands = { commands{:} ...
           {'index' 3*subj-2 'load' fileIgnore   'subject' subjs{subj} 'condition' 'Ignore' } ...
           {'index' 3*subj-1 'load' fileMemorize 'subject' subjs{subj} 'condition' 'Memorize' } ...
           {'index' 3*subj   'load' fileProbe    'subject' subjs{subj} 'condition' 'Probe' } };
end;
commands = { commands{:} { 'dipselect', 0.15 } };
[STUDY ALLEEG] = std_editset( STUDY, ALLEEG, 'name', 'Sternberg', ...
     'task', 'Sternberg', 'commands', commands, ...
     'updatedat','off', 'filename', fullfile(basedir, 'stern_autogenerated.study'));

% update workspace variables and redraw EEGLAB
CURRENTSTUDY = 1; EEG = ALLEEG; CURRENTSET = [1:length(EEG)];
[STUDY, ALLEEG] = std_checkset(STUDY, ALLEEG);
eeglab redraw

% compute and plot ERP scalp maps between 200 and 300 ms
[STUDY ALLEEG] = std_precomp(STUDY, ALLEEG, {},'interp','on','allcomps','on','erp','on');
STUDY = pop_erpparams(STUDY, 'topotime',[200 300] );
[STUDY erpdata ] = std_erpplot(STUDY,ALLEEG,'channels',{'LEYE' 'REYE' 'OZ' 'O2' 'FP1' 'FPZ' 'FP2' ...
       'AF7' 'AF3' 'AFZ' 'AF4' 'AF8' 'F9' 'F7' 'F5' 'F3' 'F1' 'FZ' 'F2' 'F4' 'F6' 'F8' 'F10' 'FT9' ...
       'FT7' 'FC5' 'FC3' 'FC1' 'FCZ' 'FC2' 'FC4' 'FC6' 'FT8' 'FT10' 'T7' 'C5' 'C3' 'C1' 'CZ' ...
       'C2' 'C4' 'C6' 'T8' 'TP9' 'TP7' 'CP5' 'CP3' 'CP1' 'CPZ' 'CP2' 'CP4' 'CP6' 'TP8' 'TP10' ...
       'P7' 'P5' 'P3' 'P1' 'PZ' 'P2' 'P4' 'P6' 'P8' 'PO9' 'PO7' 'PO3' 'POZ' 'PO4' 'PO8' 'PO10' 'O1'});

% export the data to text file
dlmwrite('erpfile.txt',squeeze(erpdata{1}), 'delimiter', '\t', 'precision', 2);
dlmwrite('erpfile.txt',squeeze(erpdata{2}),'-append', 'roffset', 1, 'delimiter', '\t', 'precision', 2);
dlmwrite('erpfile.txt',squeeze(erpdata{2}),'-append', 'roffset', 1, 'delimiter', '\t', 'precision', 2);
